[go: nahoru, domu]

Rename TextUnit.Inherit to TextUnit.Unspecified

Bug: 169704897
Test: ./gradlew test
Test: ./gradlew compose:ui:ui-text:connectedAndroidTest
Relnote: "TextUnit.Inherit is renamed to TextUnit.Unspecified in consistent with other units."
Change-Id: Ifce190ac87b01144b2fb0e7f9a8659bceed87f4e
diff --git a/compose/material/material/src/commonMain/kotlin/androidx/compose/material/Text.kt b/compose/material/material/src/commonMain/kotlin/androidx/compose/material/Text.kt
index 50cbd6e..3a5b772 100644
--- a/compose/material/material/src/commonMain/kotlin/androidx/compose/material/Text.kt
+++ b/compose/material/material/src/commonMain/kotlin/androidx/compose/material/Text.kt
@@ -47,9 +47,9 @@
  *
  * For ease of use, commonly used parameters from [TextStyle] are also present here. The order of
  * precedence is as follows:
  * - If a parameter is explicitly set here (i.e, it is _not_ `null` or [TextUnit.Inherit]), then
  * this parameter will always be used.
  * - If a parameter is _not_ set, (`null` or [TextUnit.Inherit]), then the corresponding value
  * from [style] will be used instead.
  *
  * Additionally, for [color], if [color] is not set, and [style] does not have a color, then
@@ -89,14 +89,14 @@
     text: String,
     modifier: Modifier = Modifier,
     color: Color = Color.Unspecified,
-    fontSize: TextUnit = TextUnit.Inherit,
+    fontSize: TextUnit = TextUnit.Unspecified,
     fontStyle: FontStyle? = null,
     fontWeight: FontWeight? = null,
     fontFamily: FontFamily? = null,
-    letterSpacing: TextUnit = TextUnit.Inherit,
+    letterSpacing: TextUnit = TextUnit.Unspecified,
     textDecoration: TextDecoration? = null,
     textAlign: TextAlign? = null,
-    lineHeight: TextUnit = TextUnit.Inherit,
+    lineHeight: TextUnit = TextUnit.Unspecified,
     overflow: TextOverflow = TextOverflow.Clip,
     softWrap: Boolean = true,
     maxLines: Int = Int.MAX_VALUE,
@@ -134,9 +134,9 @@
  *
  * For ease of use, commonly used parameters from [TextStyle] are also present here. The order of
  * precedence is as follows:
  * - If a parameter is explicitly set here (i.e, it is _not_ `null` or [TextUnit.Inherit]), then
  * this parameter will always be used.
  * - If a parameter is _not_ set, (`null` or [TextUnit.Inherit]), then the corresponding value
  * from [style] will be used instead.
  *
  * Additionally, for [color], if [color] is not set, and [style] does not have a color, then
@@ -178,14 +178,14 @@
     text: AnnotatedString,
     modifier: Modifier = Modifier,
     color: Color = Color.Unspecified,
-    fontSize: TextUnit = TextUnit.Inherit,
+    fontSize: TextUnit = TextUnit.Unspecified,
     fontStyle: FontStyle? = null,
     fontWeight: FontWeight? = null,
     fontFamily: FontFamily? = null,
-    letterSpacing: TextUnit = TextUnit.Inherit,
+    letterSpacing: TextUnit = TextUnit.Unspecified,
     textDecoration: TextDecoration? = null,
     textAlign: TextAlign? = null,
-    lineHeight: TextUnit = TextUnit.Inherit,
+    lineHeight: TextUnit = TextUnit.Unspecified,
     overflow: TextOverflow = TextOverflow.Clip,
     softWrap: Boolean = true,
     maxLines: Int = Int.MAX_VALUE,
@@ -47,9 +47,9 @@
  * For ease of use, commonly used parameters from [TextStyle] are also present here. The order of
  * precedence is as follows:
- * - If a parameter is explicitly set here (i.e, it is _not_ `null` or [TextUnit.Inherit]), then
- * this parameter will always be used.
- * - If a parameter is _not_ set, (`null` or [TextUnit.Inherit]), then the corresponding value
+ * - If a parameter is explicitly set here (i.e, it is _not_ `null` or [TextUnit.Unspecified]),
+ * then this parameter will always be used.
+ * - If a parameter is _not_ set, (`null` or [TextUnit.Unspecified]), then the corresponding value
  * from [style] will be used instead.
  *
@@ -134,9 +134,9 @@
  * For ease of use, commonly used parameters from [TextStyle] are also present here. The order of
  * precedence is as follows:
- * - If a parameter is explicitly set here (i.e, it is _not_ `null` or [TextUnit.Inherit]), then
- * this parameter will always be used.
- * - If a parameter is _not_ set, (`null` or [TextUnit.Inherit]), then the corresponding value
+ * - If a parameter is explicitly set here (i.e, it is _not_ `null` or [TextUnit.Unspecified]),
+ * then this parameter will always be used.
+ * - If a parameter is _not_ set, (`null` or [TextUnit.Unspecified]), then the corresponding value
  * from [style] will be used instead.
  *